==> jboss-wfk-2.1.0-torquebox-tech-preview-src.zip: jboss-wfk-2.1.0/src/torquebox-2.1.2.redhat.1/modules/stomp/src/main/java/org/torquebox/stomp/RubyStompletMetaData.java <==
/*
 * Copyright 2008-2012 Red Hat, Inc, and individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.torquebox.stomp;

import java.util.Map;

import org.jboss.as.server.deployment.AttachmentKey;
import org.jboss.as.server.deployment.AttachmentList;

public class RubyStompletMetaData {

    public static final AttachmentKey<AttachmentList<RubyStompletMetaData>> ATTACHMENTS_KEY = AttachmentKey.createList( RubyStompletMetaData.class );
    
    public RubyStompletMetaData(String name) {
        this.name = name;
    }
    
    public String getName() {
        return this.name;
    }
    
    public void setDestinationPattern(String destinationPattern) {
        this.destinationPattern = destinationPattern;
    }
    
    public String getDestinationPattern() {
        return this.destinationPattern;
    }

    public void setRubyClassName(String rubyClassName) {
        this.rubyClassName = rubyClassName;
    }
    
    public String getRubyClassName() {
        return this.rubyClassName;
    }
    
    public void setRubyRequirePath(String rubyRequirePath) {
        this.rubyRequirePath = rubyRequirePath;
    }
    
    public String getRubyRequirePath() {
        return this.rubyRequirePath;
    }
    
    public void setStompletConfig(Map<String, String> stompletConfig) {
        this.stompletConfig = stompletConfig;
    }
    
    public Map<String, String> getStompletConfig() {
        return this.stompletConfig;
    }
        
    
    private String name;
    private String destinationPattern;
    private String rubyClassName;
    private String rubyRequirePath;
    private Map<String, String> stompletConfig;

}

==> jboss-wfk-2.4.0-torquebox-tech-preview-src.zip: jboss-wfk-2.4.0/src/torquebox-2.3.2.redhat.1/modules/stomp/src/main/java/org/torquebox/stomp/RubyStompletMetaData.java <==
/*
 * Copyright 2008-2013 Red Hat, Inc, and individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.torquebox.stomp;


import org.jboss.as.server.deployment.AttachmentKey;
import org.jboss.as.server.deployment.AttachmentList;
import org.jboss.as.server.deployment.DeploymentUnit;
import org.projectodd.polyglot.stomp.StompletMetaData;

public class RubyStompletMetaData extends StompletMetaData {

    public static final AttachmentKey<AttachmentList<RubyStompletMetaData>> ATTACHMENTS_KEY = AttachmentKey.createList( RubyStompletMetaData.class );
    
    public RubyStompletMetaData(String name) {
       super( name );
    }
    
    @Override
    public void attachTo(DeploymentUnit unit) {
        super.attachTo( unit );
        unit.addToAttachmentList( ATTACHMENTS_KEY, this );
    }
    
    public void setRubyClassName(String rubyClassName) {
        this.rubyClassName = rubyClassName;
    }
    
    public String getRubyClassName() {
        return this.rubyClassName;
    }
    
    public void setRubyRequirePath(String rubyRequirePath) {
        this.rubyRequirePath = rubyRequirePath;
    }
    
    public String getRubyRequirePath() {
        return this.rubyRequirePath;
    }
    
    private String rubyClassName;
    private String rubyRequirePath;

}
